# Python Installation Steps

## Windows
 * Download Python 3.6 or later from the official site: https://www.python.org/downloads
   * Ensure that the "Add Python {version} to PATH" checkbox is selected
   * If you do not have admin privileges, uncheck the "Install launcher for all users (recommended)" checkbox

## Linux
* Run "`python3 --version`" to check which version of Python is already installed.  Python 3.6 or later is required.
   * If not installed, run "`sudo apt install python3`"
